@@ -27,13 +27,13 @@
 #include "kcalcore_export.h"
 #include "sortablelist.h"
 
-#include <KDateTime>
+#include <QDateTime>
+#include <QTimeZone>
 
-namespace KCalCore
-{
+class QTimeZone;
 
+namespace KCalCore {
 // These two are duplicates wrt. incidencebase.h
-typedef SortableList<KDateTime> DateTimeList;
 typedef SortableList<QDate> DateList;
 /* List of times */
 typedef SortableList<QTime> TimeList;
@@ -96,6 +96,7 @@ public:
     {
         return !operator==(r);
     }
+
     RecurrenceRule &operator=(const RecurrenceRule &r);
 
     /** Set if recurrence is read-only or can be changed. */
@@ -132,7 +133,7 @@ public:
       Note that the recurrence does not necessarily occur on the start date/time.
       For this to happen, it must actually match the rule.
     */
-    KDateTime startDt() const;
+    QDateTime startDt() const;
 
     /**
       Sets the recurrence start date/time.
@@ -146,7 +147,7 @@ public:
 
       @param start the recurrence's start date and time
     */
-    void setStartDt(const KDateTime &start);
+    void setStartDt(const QDateTime &start);
 
     /** Returns whether the start date has no time associated. All-Day
         means -- according to rfc2445 -- that the event has no time associate. */
@@ -163,11 +164,11 @@ public:
      * @param result if non-null, *result is updated to true if successful,
      * or false if there is no recurrence or its end date cannot be determined.
      */
-    KDateTime endDt(bool *result = nullptr) const;
+    QDateTime endDt(bool *result = nullptr) const;
 
     /** Sets the date and time of the last recurrence.
      * @param endDateTime the ending date/time after which to stop recurring. */
-    void setEndDt(const KDateTime &endDateTime);
+    void setEndDt(const QDateTime &endDateTime);
 
     /**
      * Returns -1 if the event recurs infinitely, 0 if the end date is set,
@@ -180,7 +181,7 @@ public:
     void setDuration(int duration);
 
     /** Returns the number of recurrences up to and including the date/time specified. */
-    int durationTo(const KDateTime &dt) const;
+    int durationTo(const QDateTime &dt) const;
 
     /** Returns the number of recurrences up to and including the date specified. */
     int durationTo(const QDate &date) const;
@@ -191,23 +192,23 @@ public:
       time zone rather than from the actual rule time zone.
 
       For example, shifting a rule whose start time is 09:00 America/New York,
-      using an old viewing time zone (@p oldSpec) of Europe/London, to a new time
-      zone (@p newSpec) of Europe/Paris, will result in the time being shifted
+      using an old viewing time zone (@p oldTz) of Europe/London, to a new time
+      zone (@p newTz) of Europe/Paris, will result in the time being shifted
       from 14:00 (which is the London time of the rule start) to 14:00 Paris
       time.
 
-      @param oldSpec the time specification which provides the clock times
-      @param newSpec the new time specification
+      @param oldTz the time specification which provides the clock times
+      @param newTz the new time specification
     */
-    void shiftTimes(const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec);
+    void shiftTimes(const QTimeZone &oldTz, const QTimeZone &newTz);
 
     /** Returns true if the date specified is one on which the event will
      * recur. The start date returns true only if it actually matches the rule.
      *
      * @param date date to check
-     * @param timeSpec time specification for @p date
+     * @param timeZone time specification for @p date
      */
-    bool recursOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
+    bool recursOn(const QDate &date, const QTimeZone &timeZone) const;
 
     /** Returns true if the date/time specified is one at which the event will
      * recur. Times are rounded down to the nearest minute to determine the result.
@@ -215,7 +216,7 @@ public:
      *
      * @param dt the date+time to check for recurrency
      */
-    bool recursAt(const KDateTime &dt) const;
+    bool recursAt(const QDateTime &dt) const;
 
     /** Returns true if the date matches the rules. It does not necessarily
         mean that this is an actual occurrence. In particular, the method does
@@ -224,35 +225,35 @@ public:
 
         @param dt the date+time to check for matching the rules
      */
-    bool dateMatchesRules(const KDateTime &dt) const;
+    bool dateMatchesRules(const QDateTime &dt) const;
 
     /** Returns a list of the times on the specified date at which the
      * recurrence will occur. The returned times should be interpreted in the
-     * context of @p timeSpec.
+     * context of @p timeZone.
      * @param date the date for which to find the recurrence times
-     * @param timeSpec time specification for @p date
+     * @param timeZone time specification for @p date
      */
-    TimeList recurTimesOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
+    TimeList recurTimesOn(const QDate &date, const QTimeZone &timeZone) const;
 
     /** Returns a list of all the times at which the recurrence will occur
      * between two specified times.
      *
      * There is a (large) maximum limit to the number of times returned. If due to
      * this limit the list is incomplete, this is indicated by the last entry being
-     * set to an invalid KDateTime value. If you need further values, call the
+     * set to an invalid QDateTime value. If you need further values, call the
      * method again with a start time set to just after the last valid time returned.
      * @param start inclusive start of interval
      * @param end inclusive end of interval
      * @return list of date/time values
      */
-    DateTimeList timesInInterval(const KDateTime &start, const KDateTime &end) const;
+    SortableList<QDateTime> timesInInterval(const QDateTime &start, const QDateTime &end) const;
 
     /** Returns the date and time of the next recurrence, after the specified date/time.
      * If the recurrence has no time, the next date after the specified date is returned.
      * @param preDateTime the date/time after which to find the recurrence.
      * @return date/time of next recurrence, or invalid date if none.
      */
-    KDateTime getNextDate(const KDateTime &preDateTime) const;
+    QDateTime getNextDate(const QDateTime &preDateTime) const;
 
     /** Returns the date and time of the last previous recurrence, before the specified date/time.
      * If a time later than 00:00:00 is specified and the recurrence has no time, 00:00:00 on
@@ -260,7 +261,7 @@ public:
      * @param afterDateTime the date/time before which to find the recurrence.
      * @return date/time of previous recurrence, or invalid date if none.
      */
-    KDateTime getPreviousDate(const KDateTime &afterDateTime) const;
+    QDateTime getPreviousDate(const QDateTime &afterDateTime) const;
 
     void setBySeconds(const QList<int> &bySeconds);
     void setByMinutes(const QList<int> &byMinutes);
@@ -342,7 +343,6 @@ KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, const KCalCore::Recurre
  */
 KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::RecurrenceRule::WDayPos &);
 KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, KCalCore::RecurrenceRule::WDayPos &);
-
 }
 
 Q_DECLARE_TYPEINFO(KCalCore::RecurrenceRule::WDayPos, Q_MOVABLE_TYPE);
